@@ -42,7 +42,6 @@
 
 #define GDM_LOCAL_DISPLAY_FACTORY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GDM_TYPE_LOCAL_DISPLAY_FACTORY, GdmLocalDisplayFactoryPrivate))
 
-#define CK_SEAT1_PATH                       "/org/freedesktop/ConsoleKit/Seat1"
 #define SYSTEMD_SEAT0_PATH                  "seat0"
 
 #define GDM_DBUS_PATH                       "/org/gnome/DisplayManager"
@@ -60,10 +59,8 @@ struct GdmLocalDisplayFactoryPrivate
         /* FIXME: this needs to be per seat? */
         guint            num_failures;
 
-#ifdef WITH_SYSTEMD
         guint            seat_new_id;
         guint            seat_removed_id;
-#endif
 };
 
 enum {
@@ -83,8 +80,6 @@ static void     on_display_status_changed               (GdmDisplay
                                                          GParamSpec                  *arg1,
                                                          GdmLocalDisplayFactory      *factory);
 
-static void gdm_local_display_factory_start_monitor (GdmLocalDisplayFactory *factory);
-static gboolean gdm_local_display_factory_sync_seats    (GdmLocalDisplayFactory *factory);
 static gpointer local_display_factory_object = NULL;
 
 G_DEFINE_TYPE (GdmLocalDisplayFactory, gdm_local_display_factory, GDM_TYPE_DISPLAY_FACTORY)
@@ -187,6 +182,11 @@ store_display (GdmLocalDisplayFactory *factory,
 {
         GdmDisplayStore *store;
 
+        g_signal_connect (display, "notify::status",
+                          G_CALLBACK (on_display_status_changed), factory);
+
+        g_object_weak_ref (G_OBJECT (display), (GWeakNotify)on_display_disposed, factory);
+
         store = gdm_display_factory_get_display_store (GDM_DISPLAY_FACTORY (factory));
         gdm_display_store_add (store, display);
 }
@@ -194,20 +194,8 @@ store_display (GdmLocalDisplayFactory *factory,
 static const char *
 get_seat_of_transient_display (GdmLocalDisplayFactory *factory)
 {
-        const char *seat_id = NULL;
-
         /* FIXME: don't hardcode seat */
-#ifdef WITH_SYSTEMD
-        if (LOGIND_RUNNING() > 0) {
-                seat_id = SYSTEMD_SEAT0_PATH;
-        }
-#endif
-
-        if (seat_id == NULL) {
-                seat_id = CK_SEAT1_PATH;
-        }
-
-        return seat_id;
+        return SYSTEMD_SEAT0_PATH;
 }
 
 /*
@@ -232,19 +220,7 @@ gdm_local_display_factory_create_transient_display (GdmLocalDisplayFactory *fact
 
         g_debug ("GdmLocalDisplayFactory: Creating transient display");
 
-#ifdef WITH_SYSTEMD
-        if (LOGIND_RUNNING() > 0) {
-                display = gdm_local_display_new ();
-        }
-#endif
-
-        if (display == NULL) {
-                guint32 num;
-
-                num = take_next_display_number (factory);
-
-                display = gdm_legacy_display_new (num);
-        }
+        display = gdm_local_display_new ();
 
         seat_id = get_seat_of_transient_display (factory);
         g_object_set (display,
@@ -272,26 +248,6 @@ gdm_local_display_factory_create_transient_display (GdmLocalDisplayFactory *fact
         return ret;
 }
 
-static gboolean
-ensure_initial_display_configuration (GdmLocalDisplayFactory *factory)
-{
-        GdmDisplay *display;
-
-#ifdef WITH_SYSTEMD
-        if (LOGIND_RUNNING()) {
-                if (!factory->priv->seat_new_id) {
-                        gdm_local_display_factory_start_monitor (factory);
-                }
-                return gdm_local_display_factory_sync_seats (factory);
-        }
-#endif
-
-        /* On ConsoleKit just create Seat1, and that's it. */
-        display = create_display (factory, CK_SEAT1_PATH, NULL, TRUE);
-
-        return display != NULL;
-}
-
 static void
 on_display_status_changed (GdmDisplay             *display,
                            GParamSpec             *arg1,
@@ -329,16 +285,12 @@ on_display_status_changed (GdmDisplay             *display,
                 }
                 gdm_display_store_remove (store, display);
 
-                /* if this is a local display, do a full resync.  Only
-                 * seats without displays will get created anyway.  This
-                 * ensures we get a new login screen when the user logs out,
-                 * if there isn't one.
-                 */
+                /* Create a new equivalent display if it was static */
                 if (is_local) {
                         /* reset num failures */
                         factory->priv->num_failures = 0;
 
-                        ensure_initial_display_configuration (factory);
+                        create_display (factory, seat_id, session_type, is_initial);
                 }
                 break;
         case GDM_DISPLAY_FAILED:
@@ -420,14 +372,12 @@ create_display (GdmLocalDisplayFactory *factory,
         g_debug ("GdmLocalDisplayFactory: Adding display on seat %s", seat_id);
 
 
-#ifdef WITH_SYSTEMD
         if (g_strcmp0 (seat_id, "seat0") == 0) {
                 display = gdm_local_display_new ();
                 if (session_type != NULL) {
                         g_object_set (G_OBJECT (display), "session-type", session_type, NULL);
                 }
         }
-#endif
 
         if (display == NULL) {
                 guint32 num;
@@ -452,8 +402,6 @@ create_display (GdmLocalDisplayFactory *factory,
         return display;
 }
 
-#ifdef WITH_SYSTEMD
-
 static void
 delete_display (GdmLocalDisplayFactory *factory,
                 const char             *seat_id) {
@@ -466,8 +414,7 @@ delete_display (GdmLocalDisplayFactory *factory,
         gdm_display_store_foreach_remove (store, lookup_by_seat_id, (gpointer) seat_id);
 }
 
-static gboolean
-gdm_local_display_factory_sync_seats (GdmLocalDisplayFactory *factory)
+static gboolean gdm_local_display_factory_sync_seats (GdmLocalDisplayFactory *factory)
 {
         GError *error = NULL;
         GVariant *result;
@@ -591,87 +538,25 @@ gdm_local_display_factory_stop_monitor (GdmLocalDisplayFactory *factory)
         }
 }
 
-#endif
-
-static void
-on_display_added (GdmDisplayStore        *display_store,
-                  const char             *id,
-                  GdmLocalDisplayFactory *factory)
-{
-        GdmDisplay *display;
-
-        display = gdm_display_store_lookup (display_store, id);
-
-        if (display != NULL) {
-                g_signal_connect (display, "notify::status",
-                                  G_CALLBACK (on_display_status_changed), factory);
-
-                g_object_weak_ref (G_OBJECT (display), (GWeakNotify)on_display_disposed, factory);
-        }
-}
-
-static void
-on_display_removed (GdmDisplayStore        *display_store,
-                    const char             *id,
-                    GdmLocalDisplayFactory *factory)
-{
-        GdmDisplay *display;
-
-        display = gdm_display_store_lookup (display_store, id);
-
-        if (display != NULL) {
-                g_signal_handlers_disconnect_by_func (display, G_CALLBACK (on_display_status_changed), factory);
-                g_object_weak_unref (G_OBJECT (display), (GWeakNotify)on_display_disposed, factory);
-
-        }
-}
-
 static gboolean
 gdm_local_display_factory_start (GdmDisplayFactory *base_factory)
 {
         GdmLocalDisplayFactory *factory = GDM_LOCAL_DISPLAY_FACTORY (base_factory);
-        gboolean                display_started;
-        GdmDisplayStore *store;
 
         g_return_val_if_fail (GDM_IS_LOCAL_DISPLAY_FACTORY (factory), FALSE);
 
-        store = gdm_display_factory_get_display_store (GDM_DISPLAY_FACTORY (factory));
-
-        g_signal_connect (G_OBJECT (store),
-                          "display-added",
-                          G_CALLBACK (on_display_added),
-                          factory);
-
-        g_signal_connect (G_OBJECT (store),
-                          "display-removed",
-                          G_CALLBACK (on_display_removed),
-                          factory);
-
-        display_started = ensure_initial_display_configuration (factory);
-
-        return display_started;
+        gdm_local_display_factory_start_monitor (factory);
+        return gdm_local_display_factory_sync_seats (factory);
 }
 
 static gboolean
 gdm_local_display_factory_stop (GdmDisplayFactory *base_factory)
 {
         GdmLocalDisplayFactory *factory = GDM_LOCAL_DISPLAY_FACTORY (base_factory);
-        GdmDisplayStore *store;
 
         g_return_val_if_fail (GDM_IS_LOCAL_DISPLAY_FACTORY (factory), FALSE);
 
-#ifdef WITH_SYSTEMD
         gdm_local_display_factory_stop_monitor (factory);
-#endif
-
-        store = gdm_display_factory_get_display_store (GDM_DISPLAY_FACTORY (factory));
-
-        g_signal_handlers_disconnect_by_func (G_OBJECT (store),
-                                              G_CALLBACK (on_display_added),
-                                              factory);
-        g_signal_handlers_disconnect_by_func (G_OBJECT (store),
-                                              G_CALLBACK (on_display_removed),
-                                              factory);
 
         return TRUE;
 }
@@ -818,9 +703,7 @@ gdm_local_display_factory_finalize (GObject *object)
 
         g_hash_table_destroy (factory->priv->used_display_numbers);
 
-#ifdef WITH_SYSTEMD
         gdm_local_display_factory_stop_monitor (factory);
-#endif
 
         G_OBJECT_CLASS (gdm_local_display_factory_parent_class)->finalize (object);
 }
